@@ -1,10 +1,10 @@
 """
-All configurations for pymakehelper
+All configurations for pyscrapers
 """
 import os
 
 import browser_cookie3
-from pytconf.config import Config, ParamCreator
+from pytconf import Config, ParamCreator
 
 import logging
 
