@@ -4,7 +4,7 @@ main entry point to the program
 
 
 import pylogconf.core
-from pytconf.config import register_main, get_pytconf
+from pytconf import register_main, config_arg_parse_and_launch 
 
 from pyscrapers.endpoints.group_default import register_group_default
 
@@ -23,7 +23,7 @@ def main():
     """
     pylogconf.core.setup()
     register_all_groups()
-    get_pytconf().config_arg_parse_and_launch()
+    config_arg_parse_and_launch()
 
 
 if __name__ == '__main__':
