@@ -14,6 +14,7 @@ from pornhub_api import PornhubApi
 
 import pyscrapers.core.utils
 from pyscrapers.configs import ConfigPornhubSearch, ConfigDebugRequests, ConfigCookiesSource, ConfigUrl
+from pyscrapers.core.url_set import UrlSet
 from pyscrapers.workers.youtube_dl_handlers import youtube_dl_download_url, youtube_dl_download_urls
 
 
@@ -122,20 +123,27 @@ def get_urls_from_page(root) -> List[str]:
     # video_section = video_sections[0]
     # <ul class="dropdownHottestVideos videos" id="hottestMenuSection">
     # <ul class="videos row-5-thumbs" id="mostRecentVideosSection">
-    video_sections = root.xpath('//ul[@id=\'mostRecentVideosSection\']')
-    if len(video_sections) == 0:
-        video_sections = root.xpath('//ul[contains(@class,\'pornstarsVideos\')]')
-        if len(video_sections) == 0:
-            return []
-    assert len(video_sections) == 1, len(video_sections)
-    video_section = video_sections[0]
-    elements = video_section.xpath('li[contains(@class,\'pcVideoListItem\')]')
-    urls = []
-    for element in elements:
-        key = element.attrib['_vkey']
-        url = "https://www.pornhub.com/view_video.php?viewkey={key}".format(key=key)
-        urls.append(url)
-    return urls
+    xpath_attempts = [
+        '//ul[contains(@class,\'pornstarsVideos\')]',
+        '//ul[@id=\'moreData\']',
+        '//ul[@id=\'mostRecentVideosSection\']',
+    ]
+    video_sections = []
+    for xpath_attempt in xpath_attempts:
+        video_sections = root.xpath(xpath_attempt)
+        if len(video_sections) == 1:
+            break
+    if len(video_sections) == 1:
+        video_section = video_sections[0]
+        elements = video_section.xpath('li[contains(@class,\'pcVideoListItem\')]')
+        urls = []
+        for element in elements:
+            key = element.attrib['_vkey']
+            url = "https://www.pornhub.com/view_video.php?viewkey={key}".format(key=key)
+            urls.append(url)
+        return urls
+    else:
+        return []
 
 
 def url_generator(url: str):
@@ -153,7 +161,7 @@ def download_url() -> None:
     session = requests.Session()
     session.cookies = ConfigCookiesSource.cookies
     logger = logging.getLogger(__name__)
-    urls = []
+    urls = UrlSet()
     for url in url_generator(url=ConfigUrl.url):
         logger.info("getting [{}]...".format(url))
         page = session.get(url)
@@ -168,5 +176,6 @@ def download_url() -> None:
             logger.info("url {} is [{}]".format(i, new_url))
         urls.extend(new_urls)
     session.close()
-    logger.info("got total [{}] urls".format(len(urls)))
-    youtube_dl_download_urls(urls)
+    logger.info("got total [{}] urls".format(len(urls.urls_list)))
+    logger.info("got [{}] appended twice urls".format(urls.appended_twice))
+    youtube_dl_download_urls(urls.urls_list)
